@@ -10,33 +10,28 @@ fi
 touch /opt/menu-update/lock
 
 # start user info
-/opt/menu-update/mymenu-update-info &
+/usr/bin/run-standalone.sh /opt/menu-update/mymenu-update-info &
 
 
 ###################################################################################
-###                        INFORMATION                                          ###
-### apt-get WGET is only in this script until MyMenu is on the maemo repository ###
+###          First Run - Create Backup of original hildon.menu                  ###
 ###################################################################################
-#
-# check for wget
-#if test -f /var/lib/dpkg/lock
-#then
-#rm /var/lib/dpkg/lock
-#echo lock entfernt
-#fi
-#
-#if test -f /usr/bin/wget 
-#then
-#echo wget installed
-#else
-#echo install wget
-#apt-get install wget
-#fi
-#
+
+
+
+if test -f /home/user/.config/menus/hildon.menu-old
+then
+ echo "Backup of hildon.menu exist"
+else
+ mv /home/user/.config/menus/hildon.menu /home/user/.config/menus/hildon.menu-old
+fi
+
 ###################################################################################
-### apt-get WGET is only in this script until MyMenu is on the maemo repository ###
+###          First Run END - Create Backup of original hildon.menu              ###
 ###################################################################################
 
+
+
 # pathvariable
 menu=/opt/menu-update
 menui=/opt/menu-update/mymenu
@@ -49,15 +44,15 @@ menu_old=$menu/category
 rm -r $menun/*
 cd $menun
 wget http://maemo.3ion.at/category
-wget http://maemo.3ion.at/install
+# wget http://maemo.3ion.at/install
 
 # filevariable
-install_old='$menui/install.sh'
-install_new='$menun/install'
+#install_old='$menui/install.sh'
+#install_new='$menun/install'
 hildon_menu='/opt/menu-update/mymenu/new/hildon.menu'
 
 
-# check for update 
+#check for update 
 if [ "$menu_old" -ot "$menu_new" ]; then
 cp $menun/category $menu/
 fi
@@ -132,6 +127,7 @@ done
 #     start creating menu.hildon                                                         #
 ##########################################################################################
 
+
 #### Main Menu ####
 echo '<!DOCTYPE Menu PUBLIC "-//freedesktop//DTD Menu 1.0//EN"
  "http://www.freedesktop.org/standards/menu-spec/menu-1.0.dtd">
@@ -292,7 +288,6 @@ else
 fi
 
 #### Other ####
-if [ ${#ergebniss8} -gt 0 ]; then
 echo '   
   <Menu>
     <Name>sonstige</Name>
@@ -303,9 +298,7 @@ echo '
 cat $menu/category | grep -i "sonstige" | awk -F":" '{ print $1 }' >> $hildon_menu
 echo '    </Include>
   </Menu>' >> $hildon_menu
-else
-   echo no sonstige
-fi
+
 
 #### Tools ####
 if [ ${#ergebniss10} -gt 0 ]; then
@@ -323,184 +316,15 @@ else
 fi
 echo '</Menu>' >> $hildon_menu
 
+if test -f /home/user/.config/menus/hildon.menu
+then
+rm /home/user/.config/menus/hildon.menu
+fi 
 
-/etc/init.d/hildon-desktop stop
-rm /etc/xdg/menus/hildon.menu
-cp $hildon_menu /etc/xdg/menus
-sleep 1
-/etc/init.d/hildon-desktop start
-
-
-if [ "$install_old" -ot "$install_new" ]; then
-rm $menui/install.sh
-mv $menun/install $menui/install.sh
-chmod 755 $menui/install.sh
-$menui/install.sh
-else
-echo no update
-fi
-
-
+cp $hildon_menu /home/user/.config/menus
 
 rm /opt/menu-update/lock
 
-## FINAL TEST
-echo FINAL TEST
-COUNTER=10
-until [  $COUNTER -lt 1 ]; do
-check=`ps axf | pgrep hildon-desktop`
-
-if [ "$COUNTER" = 10 ]; then
- echo $check >> 10
-  elif [ "$COUNTER" = 1 ]; then
-    echo $check >> 1
-else
-echo 
-fi
-sleep 1
-    let COUNTER-=1
-done
-
-if [ "$(cat 10)" = "$(cat 1)"  ]; then
- echo NO ERROR
-else
- echo ERROR = RESTORING ORIGINAL SETUP
- if [ "$(uname -r)" = "2.6.28-omap1" ]; then
-
-
-# remove configuration
-filename="/etc/xdg/menus/hildon.menu"
-if test -f /etc/xdg/menus/hildon.menu
-then
- rm $filename
-fi 
-
-touch $filename
-
-
-# Set Menu to orginal strukture.
-#DEBHELPER#
-
-echo '<!DOCTYPE Menu PUBLIC "-//freedesktop//DTD Menu 1.0//EN"
- "http://www.freedesktop.org/standards/menu-spec/menu-1.0.dtd">
-
-<Menu>
-
-  <Name>Main</Name>
-
-  <!-- Search only in the hildon directory. -->
-  <AppDir>/usr/share/applications/hildon</AppDir>
-  <DirectoryDir>/usr/share/applications/hildon</DirectoryDir>
-
-  <Include>
-    <Filename>browser.desktop</Filename>
-    <Filename>mediaplayer.desktop</Filename>
-    <Filename>calendar.desktop</Filename>
-    <Filename>image-viewer.desktop</Filename>
-    <Filename>osso-addressbook.desktop</Filename>
-    <Filename>rtcom-call-ui.desktop</Filename>
-    <Filename>nokia-maps.desktop</Filename>
-    <Filename>camera-ui.desktop</Filename>
-    <Filename>modest.desktop</Filename>
-    <Filename>rtcom-messaging-ui.desktop</Filename>
-    <Filename>worldclock.desktop</Filename>
-    <Filename>osso_calculator.desktop</Filename>
-    <Filename>ovi.desktop</Filename>
-    <Filename>hildon-control-panel.desktop</Filename>
-  </Include>
-
-  <Layout>
-    <Filename>browser.desktop</Filename>
-    <Filename>mediaplayer.desktop</Filename>
-    <Filename>calendar.desktop</Filename>
-    <Filename>image-viewer.desktop</Filename>
-    <Filename>osso-addressbook.desktop</Filename>
-    <Filename>rtcom-call-ui.desktop</Filename>
-    <Filename>nokia-maps.desktop</Filename>
-    <Filename>camera-ui.desktop</Filename>
-    <Filename>modest.desktop</Filename>
-    <Filename>rtcom-messaging-ui.desktop</Filename>
-    <Filename>worldclock.desktop</Filename>
-    <Filename>osso_calculator.desktop</Filename>
-    <Filename>ovi.desktop</Filename>
-    <Filename>hildon-control-panel.desktop</Filename>
-    <Menuname>Applications</Menuname>
-    <Merge type="all"/>
-  </Layout>
-
-  <MergeDir>hildon/</MergeDir>
-
-</Menu> ' >> $filename
-
-
-/etc/init.d/hildon-desktop stop
-sleep 5
-/etc/init.d/hildon-desktop start
-
-exit 1
-
- else
-
-# remove configuration
-filename="/etc/xdg/menus/hildon.menu"
-if test -f /etc/xdg/menus/hildon.menu
-then
- rm $filename
-fi 
-
-touch $filename
-
-
-# Set Menu to orginal strukture.
-#DEBHELPER#
-
-echo '<!DOCTYPE Menu PUBLIC "-//freedesktop//DTD Menu 1.0//EN"
- "http://www.freedesktop.org/standards/menu-spec/menu-1.0.dtd">
- 
- <Menu>
- 
-   <Name>Main</Name>
-   
-     <!-- Search the default locations -->
-      <AppDir>/usr/share/applications/hildon</AppDir>
-      <DirectoryDir>/usr/share/applications/hildon</DirectoryDir>
-         
-      <Include>
-        <Filename>browser.desktop</Filename>
-        <Filename>mediaplayer.desktop</Filename>
-        <Filename>calendar.desktop</Filename>
-        <Filename>image-viewer.desktop</Filename>
-        <Filename>osso-addressbook.desktop</Filename>
-        <Filename>rtcom-call-ui.desktop</Filename>
-        <Filename>nokia-maps.desktop</Filename>
-        <Filename>camera-ui.desktop</Filename>
-        <Filename>modest.desktop</Filename>
-        <Filename>rtcom-messaging-ui.desktop</Filename>
-        <Filename>worldclock.desktop</Filename>
-        <Filename>osso_calculator.desktop</Filename>
-        <Filename>ovi.desktop</Filename>
-        <Filename>hildon-control-panel.desktop</Filename>
-      </Include>
-                                          
-      <Menu>
-        <Name>Applications</Name>
-        <Directory>applications.directory</Directory>
-        <OnlyUnallocated/>
-   <Include>
-     <All/>
-     </Include>
-   </Menu>
-   </Menu> ' >> $filename
-
-
-/etc/init.d/hildon-desktop stop
-sleep 5
-/etc/init.d/hildon-desktop start
-exit 1
- fi
-fi
-
-
 killall mymenu-update-info
 exit 0
 
